@@ -11,6 +11,7 @@ import webbrowser
 import click
 import rich
 from rich import prompt
+from rich.console import Console
 
 import rocks
 
@@ -81,18 +82,33 @@ def info(id_):
 
 
 @cli_rocks.command()
-def parameters():
+@click.option("--units", "-u", is_flag=True, help="Echo the parameter units.")
+def parameters(units):
     """Print the ssoCard structure and its description."""
 
-    if not rocks.PATH_META["description"].is_file():
-        rocks.utils.retrieve_json_from_ssodnet("description")
+    which = "description" if not units else "units"
 
-    with open(rocks.PATH_META["description"], "r") as file_:
+    if not rocks.PATH_META[which].is_file():
+        rocks.utils.retrieve_json_from_ssodnet(which)
+
+    with open(rocks.PATH_META[which], "r") as file_:
         DESC = json.load(file_)
 
     rich.print(DESC)
 
 
+@cli_rocks.command()
+@click.argument("id_")
+def aliases(id_):
+    """Echo the aliases of an asteroid."""
+
+    name, number, ssodnetid = rocks.identify(id_, return_id=True)  # type: ignore
+
+    aliases = rocks.index.get_aliases(ssodnetid)
+
+    rich.print(f"({number}) {name}, aka \n {aliases}")
+
+
 @cli_rocks.command()
 def status():
     """Echo the status of the ssoCards and datacloud catalogues."""
@@ -138,7 +154,7 @@ def status():
             "[blue][0][/blue] Do nothing "
             "[blue][1][/blue] Clear the cache "
             "[blue][2][/blue] Update the data",
-            choices=["0", "1", "2"],
+            choices=["0", "1", "2", "3"],
             show_choices=False,
             default="1",
         )
@@ -169,6 +185,10 @@ def status():
             rich.print("\n(3/3) Updating the cached datacloud catalogues..")
             rocks.utils.update_datacloud_catalogues(cached_catalogues)
 
+        elif decision == "3":
+            with Console().status("Observing all asteroids.. [~11GB]", spinner="earth"):
+                rocks.utils.cache_all_ssocards()
+
     # ------
     # Update asteroid name-number index
     response = prompt.Prompt.ask(
@@ -181,7 +201,7 @@ def status():
     )
 
     if response == "1":
-        rocks.utils._build_index()
+        rocks.index._build_index()
 
 
 def echo():
