@@ -24,6 +24,7 @@ class Error(pydantic.BaseModel):
 
 class Value(pydantic.BaseModel):
     error: Error = Error(**{})
+    error_: Optional[float] = np.nan
     value: Optional[float] = np.nan
     path_unit: str = ""
 
@@ -39,6 +40,17 @@ class Value(pydantic.BaseModel):
         else:
             return f"{self.value:.4} +- ({self.error.max_:.4}, {self.error.min_:.4}) {unit}"
 
+    @pydantic.root_validator(pre=True)
+    def _compute_mean_error(cls, values):
+
+        if "error" in values:
+            if "min" in values["error"] and "max" in values["error"]:
+                values["error_"] = np.mean(
+                    [np.abs(values["error"][which]) for which in ["min", "max"]]
+                )
+
+        return values
+
 
 # The second lowest level is the Parameter
 class Parameter(pydantic.BaseModel):
@@ -159,20 +171,13 @@ class Family(Parameter):
     family_status: Optional[str] = ""
 
 
-class PairMembers(Parameter):
+class PairMember(Parameter):
+    age: Value = Value(**{})
+    distance: Optional[float] = np.nan
     sibling_name: Optional[str] = ""
-    pair_delta_v: Optional[float] = np.nan
-    pair_delta_a: Optional[float] = np.nan
-    pair_delta_e: Optional[float] = np.nan
-    pair_delta_i: Optional[float] = np.nan
     sibling_number: Optional[int] = None
 
 
-class Pair(Parameter):
-    members: List[PairMembers] = [PairMembers(**{})]
-    bibref: List[Bibref] = [Bibref(**{})]
-
-
 class TisserandParameter(Value):
     method: List[Method] = []
     bibref: List[Bibref] = []
@@ -190,7 +195,7 @@ class Yarkovsky(Parameter):
 
 
 class DynamicalParameters(Parameter):
-    pair: Pair = Pair(**{})
+    pair: List[PairMember] = [PairMember(**{})]
     family: Family = Family(**{})
     tisserand_parameter: TisserandParameter = TisserandParameter(**{})
     yarkovsky: Yarkovsky = Yarkovsky(**{})
@@ -287,9 +292,10 @@ class Spin(Parameter):
 
 class Taxonomy(Parameter):
     class_: Optional[str] = pydantic.Field("", alias="class")
-    scheme: Optional[str] = ""
     bibref: Optional[List[Bibref]] = [Bibref(**{})]
     method: Optional[List[Method]] = [Method(**{})]
+    scheme: Optional[str] = ""
+    complex: Optional[str] = ""
     waverange: Optional[str] = ""
 
     def __str__(self):
@@ -501,10 +507,28 @@ class Rock(pydantic.BaseModel):
                 # Dynamically remove offending parts of the ssoCard
                 offending_part = ssocard
 
-                for location in error["loc"][:-1]:
-                    offending_part = offending_part[location]
+                location_list = error["loc"][:-1]
 
-                del offending_part[error["loc"][-1]]
+                if any(
+                    [property_ in location_list for property_ in ["taxonomy", "spin"]]
+                ):
+                    for property_ in ["taxonomy", "spin"]:
+                        if property_ in location_list:
+                            # these are lists instead of dicts and the indices are flipped
+                            # eg taxonomy bibref 0 becomes taxonomy 0 bibref
+                            idx = location_list.index(property_)
+                            entry, idx_list = location_list[idx + 1 : idx + 3]
+
+                            try:
+                                del ssocard["parameters"]["physical"][property_]
+                            except KeyError:
+                                pass
+                else:
+
+                    for location in error["loc"][:-1]:
+                        offending_part = offending_part[location]
+
+                    del offending_part[error["loc"][-1]]
 
             super().__init__(**ssocard)  # type: ignore
 
