@@ -1,5 +1,6 @@
 #!/usr/bin/env python
 """Implement the Datacloud catalogue pydantic models."""
+
 from typing import List, Optional
 
 import numpy as np
@@ -111,7 +112,7 @@ CATALOGUES = {
     "masses": {
         "attr_name": "masses",
         "ssodnet_name": "masses",
-        "print_columns": ["mass", "err_mass", "method", "shortbib"],
+        "print_columns": ["mass", "err_mass_up", "err_mass_down", "method", "shortbib"],
     },
     "mpcatobs": {
         "attr_name": "mpcatobs",
@@ -147,7 +148,7 @@ CATALOGUES = {
         "ssodnet_name": "taxonomy",
         "print_columns": [
             "class_",
-            "complex_",
+            "complex",
             "method",
             "waverange",
             "scheme",
@@ -172,7 +173,7 @@ def pretty_print(rock, catalogue, parameter):
     """Print datacloud catalogue using a nice table format.
 
     Parameters
-    ==========
+    ----------
     rock : rocks.Rock
         The Rock instance the catalogue is associated to.
     catalogue : pd.DataFrame
@@ -202,6 +203,10 @@ def pretty_print(rock, catalogue, parameter):
         caption=caption,
     )
 
+    # Sort catalogue by year of reference
+    if "year" in catalogue.columns:
+        catalogue = catalogue.sort_values("year").reset_index()
+
     # The columns depend on the catalogue
     columns = CATALOGUES[parameter]["print_columns"]
 
@@ -258,7 +263,9 @@ class DataCloudDataFrame(pd.DataFrame):
 
     def plot(self, parameter, **kwargs):
         """Plot the parameter of the catalogue."""
-        return rocks.plots.plot(self, parameter, **kwargs)
+        from . import plots
+
+        return plots.plot(self, parameter, **kwargs)
 
     def weighted_average(self, parameter):
         """Compute the weighted average of the parameter using the preferred
@@ -459,7 +466,8 @@ class Masses(Catalogue):
 
     year: List[Optional[int]] = [None]
     mass: List[float] = [np.nan]
-    err_mass: List[float] = [np.nan]
+    err_mass_up: List[float] = [np.nan]
+    err_mass_down: List[float] = [np.nan]
 
     preferred: List[bool] = [False]
 
@@ -520,7 +528,7 @@ class Taxonomies(Catalogue):
     waverange: List[str] = [""]
     method: List[str] = [""]
     scheme: List[str] = [""]
-    complex_: List[str] = pydantic.Field([""], alias="complex")
+    complex: List[str] = pydantic.Field([""], alias="complex")
     class_: List[str] = pydantic.Field([""], alias="class")
     shortbib: List[str] = [""]
 
